/*
 *	editlev.h
 *	AYM 1998-09-06
 */


char *find_level (const char *name_given);
void EditLevel (const char *, bool);

